// dev/mod.rs
//
// This is the mod.rs file that is in control of the dev section of the kernel.


// Drivers
pub mod drivers;

// Keyboard support
pub mod kbd;
